@@ -1,9 +1,9 @@
-from typing import Dict, Any
+from typing import Any, Dict
 
 import torch
 from torch.nn import Linear
 
-from quaterion_models.heads import EncoderHead
+from quaterion_models.heads.encoder_head import EncoderHead
 
 
 class SoftmaxEmbeddingsHead(EncoderHead):
