@@ -1,5 +1,5 @@
 # TODO: Split them into separate files once we have more of them.
-from typing import Union, Tuple, List, Dict, Any, Callable
+from typing import Any, Callable, Dict, List, Tuple, Union
 
 from torch import Tensor
 
